package containers

import (
	"os"
	"testing"
	"time"

	"github.com/stretchr/testify/assert"
)

func getTestDockerSock() string {
	dockerSocket := os.Getenv("DOCKER_SOCKET")
	if dockerSocket == "" {
		return "unix:///run/user/1000/podman/podman.sock"
	}
	return dockerSocket
}

func TestGetProcesses(t *testing.T) {
	driver := Driver{
		DockerSock: getTestDockerSock(),
		BindIPHTTP: "127.0.0.1",
		BindIPSSH:  "127.0.0.1",
	}

	driver.Remove("test")

	_, err := driver.Create("test", "docker.io/library/busybox", "/tmp", 8990, 8922, 1, 128, []string{"sleep", "3600"})
	assert.Nil(t, err)

	err = driver.Start("test")
	assert.Nil(t, err)

	time.Sleep(5 * time.Second)

	processes, err := driver.GetProcesses("test")
	assert.Nil(t, err)
	assert.Contains(t, processes, "sleep 3600")

	driver.Remove("test")
}
